# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.4.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKImageGridPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if getattr(globals().get("__spec__"), "parent", None) or __package__ or "." in __name__:
    from . import _itkWarpImageFilterPython
else:
    import _itkWarpImageFilterPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.itkImageToImageFilterAPython
import itk.itkImageRegionPython
import itk.itkSizePython
import itk.pyBasePython
import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.vnl_matrix_fixedPython
import itk.vnl_vectorPython
import itk.stdcomplexPython
import itk.vnl_matrixPython
import itk.itkPointPython
import itk.vnl_vector_refPython
import itk.itkFixedArrayPython
import itk.itkVectorPython
import itk.itkCovariantVectorPython
import itk.itkIndexPython
import itk.itkOffsetPython
import itk.itkImageSourcePython
import itk.itkImagePython
import itk.itkRGBPixelPython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkRGBAPixelPython
import itk.itkImageSourceCommonPython
import itk.itkVectorImagePython
import itk.itkVariableLengthVectorPython
import itk.itkPhasedArray3DSpecialCoordinatesImagePython
import itk.itkImageToImageFilterCommonPython
import itk.itkInterpolateImageFunctionPython
import itk.itkImageFunctionBasePython
import itk.itkFunctionBasePython
import itk.itkContinuousIndexPython
import itk.itkArrayPython

def itkWarpImageFilterIF2IF2IVF22_New():
    return itkWarpImageFilterIF2IF2IVF22.New()

class itkWarpImageFilterIF2IF2IVF22(itk.itkImageToImageFilterAPython.itkImageToImageFilterIF2IF2):
    r"""Proxy of C++ itkWarpImageFilterIF2IF2IVF22 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkWarpImageFilterIF2IF2IVF22_Pointer"""
        return _itkWarpImageFilterPython.itkWarpImageFilterIF2IF2IVF22___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkWarpImageFilterIF2IF2IVF22_Pointer"""
        return _itkWarpImageFilterPython.itkWarpImageFilterIF2IF2IVF22_Clone(self)

    def SetDisplacementField(self, _arg):
        r"""
        SetDisplacementField(self, _arg)

        Parameters
        ----------
        _arg: itkImageVF22 const *

        """
        return _itkWarpImageFilterPython.itkWarpImageFilterIF2IF2IVF22_SetDisplacementField(self, _arg)

    def GetDisplacementField(self):
        r"""GetDisplacementField(self) -> itkImageVF22"""
        return _itkWarpImageFilterPython.itkWarpImageFilterIF2IF2IVF22_GetDisplacementField(self)

    def SetInterpolator(self, _arg):
        r"""
        SetInterpolator(self, _arg)

        Parameters
        ----------
        _arg: itkInterpolateImageFunctionIF2D *

        """
        return _itkWarpImageFilterPython.itkWarpImageFilterIF2IF2IVF22_SetInterpolator(self, _arg)

    def GetModifiableInterpolator(self):
        r"""GetModifiableInterpolator(self) -> itkInterpolateImageFunctionIF2D"""
        return _itkWarpImageFilterPython.itkWarpImageFilterIF2IF2IVF22_GetModifiableInterpolator(self)

    def GetInterpolator(self, *args):
        r"""
        GetInterpolator(self) -> itkInterpolateImageFunctionIF2D
        GetInterpolator(self) -> itkInterpolateImageFunctionIF2D
        """
        return _itkWarpImageFilterPython.itkWarpImageFilterIF2IF2IVF22_GetInterpolator(self, *args)

    def SetOutputSpacing(self, *args):
        r"""
        SetOutputSpacing(self, _arg)

        Parameters
        ----------
        _arg: itkVectorD2

        SetOutputSpacing(self, spacing)

        Parameters
        ----------
        spacing: double const *

        """
        return _itkWarpImageFilterPython.itkWarpImageFilterIF2IF2IVF22_SetOutputSpacing(self, *args)

    def GetOutputSpacing(self):
        r"""GetOutputSpacing(self) -> itkVectorD2"""
        return _itkWarpImageFilterPython.itkWarpImageFilterIF2IF2IVF22_GetOutputSpacing(self)

    def SetOutputOrigin(self, *args):
        r"""
        SetOutputOrigin(self, _arg)

        Parameters
        ----------
        _arg: itkPointD2

        SetOutputOrigin(self, origin)

        Parameters
        ----------
        origin: double const *

        """
        return _itkWarpImageFilterPython.itkWarpImageFilterIF2IF2IVF22_SetOutputOrigin(self, *args)

    def GetOutputOrigin(self):
        r"""GetOutputOrigin(self) -> itkPointD2"""
        return _itkWarpImageFilterPython.itkWarpImageFilterIF2IF2IVF22_GetOutputOrigin(self)

    def SetOutputDirection(self, _arg):
        r"""
        SetOutputDirection(self, _arg)

        Parameters
        ----------
        _arg: itkMatrixD22

        """
        return _itkWarpImageFilterPython.itkWarpImageFilterIF2IF2IVF22_SetOutputDirection(self, _arg)

    def GetOutputDirection(self):
        r"""GetOutputDirection(self) -> itkMatrixD22"""
        return _itkWarpImageFilterPython.itkWarpImageFilterIF2IF2IVF22_GetOutputDirection(self)

    def SetOutputParametersFromImage(self, image):
        r"""
        SetOutputParametersFromImage(self, image)

        Parameters
        ----------
        image: itkImageBase2 const *

        """
        return _itkWarpImageFilterPython.itkWarpImageFilterIF2IF2IVF22_SetOutputParametersFromImage(self, image)

    def SetOutputStartIndex(self, _arg):
        r"""
        SetOutputStartIndex(self, _arg)

        Parameters
        ----------
        _arg: itkIndex2

        """
        return _itkWarpImageFilterPython.itkWarpImageFilterIF2IF2IVF22_SetOutputStartIndex(self, _arg)

    def GetOutputStartIndex(self):
        r"""GetOutputStartIndex(self) -> itkIndex2"""
        return _itkWarpImageFilterPython.itkWarpImageFilterIF2IF2IVF22_GetOutputStartIndex(self)

    def SetOutputSize(self, _arg):
        r"""
        SetOutputSize(self, _arg)

        Parameters
        ----------
        _arg: itkSize2

        """
        return _itkWarpImageFilterPython.itkWarpImageFilterIF2IF2IVF22_SetOutputSize(self, _arg)

    def GetOutputSize(self):
        r"""GetOutputSize(self) -> itkSize2"""
        return _itkWarpImageFilterPython.itkWarpImageFilterIF2IF2IVF22_GetOutputSize(self)

    def SetEdgePaddingValue(self, _arg):
        r"""
        SetEdgePaddingValue(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkWarpImageFilterPython.itkWarpImageFilterIF2IF2IVF22_SetEdgePaddingValue(self, _arg)

    def GetEdgePaddingValue(self):
        r"""GetEdgePaddingValue(self) -> float"""
        return _itkWarpImageFilterPython.itkWarpImageFilterIF2IF2IVF22_GetEdgePaddingValue(self)

    def GenerateOutputInformation(self):
        r"""GenerateOutputInformation(self)"""
        return _itkWarpImageFilterPython.itkWarpImageFilterIF2IF2IVF22_GenerateOutputInformation(self)

    def GenerateInputRequestedRegion(self):
        r"""GenerateInputRequestedRegion(self)"""
        return _itkWarpImageFilterPython.itkWarpImageFilterIF2IF2IVF22_GenerateInputRequestedRegion(self)

    def BeforeThreadedGenerateData(self):
        r"""BeforeThreadedGenerateData(self)"""
        return _itkWarpImageFilterPython.itkWarpImageFilterIF2IF2IVF22_BeforeThreadedGenerateData(self)

    def AfterThreadedGenerateData(self):
        r"""AfterThreadedGenerateData(self)"""
        return _itkWarpImageFilterPython.itkWarpImageFilterIF2IF2IVF22_AfterThreadedGenerateData(self)
    SameDimensionCheck1 = _itkWarpImageFilterPython.itkWarpImageFilterIF2IF2IVF22_SameDimensionCheck1
    
    SameDimensionCheck2 = _itkWarpImageFilterPython.itkWarpImageFilterIF2IF2IVF22_SameDimensionCheck2
    
    InputHasNumericTraitsCheck = _itkWarpImageFilterPython.itkWarpImageFilterIF2IF2IVF22_InputHasNumericTraitsCheck
    
    DisplacementFieldHasNumericTraitsCheck = _itkWarpImageFilterPython.itkWarpImageFilterIF2IF2IVF22_DisplacementFieldHasNumericTraitsCheck
    
    __swig_destroy__ = _itkWarpImageFilterPython.delete_itkWarpImageFilterIF2IF2IVF22

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkWarpImageFilterIF2IF2IVF22

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkWarpImageFilterPython.itkWarpImageFilterIF2IF2IVF22_cast(obj)

    def New(*args, **kargs):
        """New() -> itkWarpImageFilterIF2IF2IVF22

        Create a new object of the class itkWarpImageFilterIF2IF2IVF22 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkWarpImageFilterIF2IF2IVF22.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkWarpImageFilterIF2IF2IVF22.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkWarpImageFilterIF2IF2IVF22.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkWarpImageFilterIF2IF2IVF22 in _itkWarpImageFilterPython:
_itkWarpImageFilterPython.itkWarpImageFilterIF2IF2IVF22_swigregister(itkWarpImageFilterIF2IF2IVF22)

def itkWarpImageFilterIF3IF3IVF33_New():
    return itkWarpImageFilterIF3IF3IVF33.New()

class itkWarpImageFilterIF3IF3IVF33(itk.itkImageToImageFilterAPython.itkImageToImageFilterIF3IF3):
    r"""Proxy of C++ itkWarpImageFilterIF3IF3IVF33 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkWarpImageFilterIF3IF3IVF33_Pointer"""
        return _itkWarpImageFilterPython.itkWarpImageFilterIF3IF3IVF33___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkWarpImageFilterIF3IF3IVF33_Pointer"""
        return _itkWarpImageFilterPython.itkWarpImageFilterIF3IF3IVF33_Clone(self)

    def SetDisplacementField(self, _arg):
        r"""
        SetDisplacementField(self, _arg)

        Parameters
        ----------
        _arg: itkImageVF33 const *

        """
        return _itkWarpImageFilterPython.itkWarpImageFilterIF3IF3IVF33_SetDisplacementField(self, _arg)

    def GetDisplacementField(self):
        r"""GetDisplacementField(self) -> itkImageVF33"""
        return _itkWarpImageFilterPython.itkWarpImageFilterIF3IF3IVF33_GetDisplacementField(self)

    def SetInterpolator(self, _arg):
        r"""
        SetInterpolator(self, _arg)

        Parameters
        ----------
        _arg: itkInterpolateImageFunctionIF3D *

        """
        return _itkWarpImageFilterPython.itkWarpImageFilterIF3IF3IVF33_SetInterpolator(self, _arg)

    def GetModifiableInterpolator(self):
        r"""GetModifiableInterpolator(self) -> itkInterpolateImageFunctionIF3D"""
        return _itkWarpImageFilterPython.itkWarpImageFilterIF3IF3IVF33_GetModifiableInterpolator(self)

    def GetInterpolator(self, *args):
        r"""
        GetInterpolator(self) -> itkInterpolateImageFunctionIF3D
        GetInterpolator(self) -> itkInterpolateImageFunctionIF3D
        """
        return _itkWarpImageFilterPython.itkWarpImageFilterIF3IF3IVF33_GetInterpolator(self, *args)

    def SetOutputSpacing(self, *args):
        r"""
        SetOutputSpacing(self, _arg)

        Parameters
        ----------
        _arg: itkVectorD3

        SetOutputSpacing(self, spacing)

        Parameters
        ----------
        spacing: double const *

        """
        return _itkWarpImageFilterPython.itkWarpImageFilterIF3IF3IVF33_SetOutputSpacing(self, *args)

    def GetOutputSpacing(self):
        r"""GetOutputSpacing(self) -> itkVectorD3"""
        return _itkWarpImageFilterPython.itkWarpImageFilterIF3IF3IVF33_GetOutputSpacing(self)

    def SetOutputOrigin(self, *args):
        r"""
        SetOutputOrigin(self, _arg)

        Parameters
        ----------
        _arg: itkPointD3

        SetOutputOrigin(self, origin)

        Parameters
        ----------
        origin: double const *

        """
        return _itkWarpImageFilterPython.itkWarpImageFilterIF3IF3IVF33_SetOutputOrigin(self, *args)

    def GetOutputOrigin(self):
        r"""GetOutputOrigin(self) -> itkPointD3"""
        return _itkWarpImageFilterPython.itkWarpImageFilterIF3IF3IVF33_GetOutputOrigin(self)

    def SetOutputDirection(self, _arg):
        r"""
        SetOutputDirection(self, _arg)

        Parameters
        ----------
        _arg: itkMatrixD33

        """
        return _itkWarpImageFilterPython.itkWarpImageFilterIF3IF3IVF33_SetOutputDirection(self, _arg)

    def GetOutputDirection(self):
        r"""GetOutputDirection(self) -> itkMatrixD33"""
        return _itkWarpImageFilterPython.itkWarpImageFilterIF3IF3IVF33_GetOutputDirection(self)

    def SetOutputParametersFromImage(self, image):
        r"""
        SetOutputParametersFromImage(self, image)

        Parameters
        ----------
        image: itkImageBase3 const *

        """
        return _itkWarpImageFilterPython.itkWarpImageFilterIF3IF3IVF33_SetOutputParametersFromImage(self, image)

    def SetOutputStartIndex(self, _arg):
        r"""
        SetOutputStartIndex(self, _arg)

        Parameters
        ----------
        _arg: itkIndex3

        """
        return _itkWarpImageFilterPython.itkWarpImageFilterIF3IF3IVF33_SetOutputStartIndex(self, _arg)

    def GetOutputStartIndex(self):
        r"""GetOutputStartIndex(self) -> itkIndex3"""
        return _itkWarpImageFilterPython.itkWarpImageFilterIF3IF3IVF33_GetOutputStartIndex(self)

    def SetOutputSize(self, _arg):
        r"""
        SetOutputSize(self, _arg)

        Parameters
        ----------
        _arg: itkSize3

        """
        return _itkWarpImageFilterPython.itkWarpImageFilterIF3IF3IVF33_SetOutputSize(self, _arg)

    def GetOutputSize(self):
        r"""GetOutputSize(self) -> itkSize3"""
        return _itkWarpImageFilterPython.itkWarpImageFilterIF3IF3IVF33_GetOutputSize(self)

    def SetEdgePaddingValue(self, _arg):
        r"""
        SetEdgePaddingValue(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkWarpImageFilterPython.itkWarpImageFilterIF3IF3IVF33_SetEdgePaddingValue(self, _arg)

    def GetEdgePaddingValue(self):
        r"""GetEdgePaddingValue(self) -> float"""
        return _itkWarpImageFilterPython.itkWarpImageFilterIF3IF3IVF33_GetEdgePaddingValue(self)

    def GenerateOutputInformation(self):
        r"""GenerateOutputInformation(self)"""
        return _itkWarpImageFilterPython.itkWarpImageFilterIF3IF3IVF33_GenerateOutputInformation(self)

    def GenerateInputRequestedRegion(self):
        r"""GenerateInputRequestedRegion(self)"""
        return _itkWarpImageFilterPython.itkWarpImageFilterIF3IF3IVF33_GenerateInputRequestedRegion(self)

    def BeforeThreadedGenerateData(self):
        r"""BeforeThreadedGenerateData(self)"""
        return _itkWarpImageFilterPython.itkWarpImageFilterIF3IF3IVF33_BeforeThreadedGenerateData(self)

    def AfterThreadedGenerateData(self):
        r"""AfterThreadedGenerateData(self)"""
        return _itkWarpImageFilterPython.itkWarpImageFilterIF3IF3IVF33_AfterThreadedGenerateData(self)
    SameDimensionCheck1 = _itkWarpImageFilterPython.itkWarpImageFilterIF3IF3IVF33_SameDimensionCheck1
    
    SameDimensionCheck2 = _itkWarpImageFilterPython.itkWarpImageFilterIF3IF3IVF33_SameDimensionCheck2
    
    InputHasNumericTraitsCheck = _itkWarpImageFilterPython.itkWarpImageFilterIF3IF3IVF33_InputHasNumericTraitsCheck
    
    DisplacementFieldHasNumericTraitsCheck = _itkWarpImageFilterPython.itkWarpImageFilterIF3IF3IVF33_DisplacementFieldHasNumericTraitsCheck
    
    __swig_destroy__ = _itkWarpImageFilterPython.delete_itkWarpImageFilterIF3IF3IVF33

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkWarpImageFilterIF3IF3IVF33

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkWarpImageFilterPython.itkWarpImageFilterIF3IF3IVF33_cast(obj)

    def New(*args, **kargs):
        """New() -> itkWarpImageFilterIF3IF3IVF33

        Create a new object of the class itkWarpImageFilterIF3IF3IVF33 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkWarpImageFilterIF3IF3IVF33.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkWarpImageFilterIF3IF3IVF33.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkWarpImageFilterIF3IF3IVF33.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkWarpImageFilterIF3IF3IVF33 in _itkWarpImageFilterPython:
_itkWarpImageFilterPython.itkWarpImageFilterIF3IF3IVF33_swigregister(itkWarpImageFilterIF3IF3IVF33)

def itkWarpImageFilterISS2ISS2IVF22_New():
    return itkWarpImageFilterISS2ISS2IVF22.New()

class itkWarpImageFilterISS2ISS2IVF22(itk.itkImageToImageFilterAPython.itkImageToImageFilterISS2ISS2):
    r"""Proxy of C++ itkWarpImageFilterISS2ISS2IVF22 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkWarpImageFilterISS2ISS2IVF22_Pointer"""
        return _itkWarpImageFilterPython.itkWarpImageFilterISS2ISS2IVF22___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkWarpImageFilterISS2ISS2IVF22_Pointer"""
        return _itkWarpImageFilterPython.itkWarpImageFilterISS2ISS2IVF22_Clone(self)

    def SetDisplacementField(self, _arg):
        r"""
        SetDisplacementField(self, _arg)

        Parameters
        ----------
        _arg: itkImageVF22 const *

        """
        return _itkWarpImageFilterPython.itkWarpImageFilterISS2ISS2IVF22_SetDisplacementField(self, _arg)

    def GetDisplacementField(self):
        r"""GetDisplacementField(self) -> itkImageVF22"""
        return _itkWarpImageFilterPython.itkWarpImageFilterISS2ISS2IVF22_GetDisplacementField(self)

    def SetInterpolator(self, _arg):
        r"""
        SetInterpolator(self, _arg)

        Parameters
        ----------
        _arg: itkInterpolateImageFunctionISS2D *

        """
        return _itkWarpImageFilterPython.itkWarpImageFilterISS2ISS2IVF22_SetInterpolator(self, _arg)

    def GetModifiableInterpolator(self):
        r"""GetModifiableInterpolator(self) -> itkInterpolateImageFunctionISS2D"""
        return _itkWarpImageFilterPython.itkWarpImageFilterISS2ISS2IVF22_GetModifiableInterpolator(self)

    def GetInterpolator(self, *args):
        r"""
        GetInterpolator(self) -> itkInterpolateImageFunctionISS2D
        GetInterpolator(self) -> itkInterpolateImageFunctionISS2D
        """
        return _itkWarpImageFilterPython.itkWarpImageFilterISS2ISS2IVF22_GetInterpolator(self, *args)

    def SetOutputSpacing(self, *args):
        r"""
        SetOutputSpacing(self, _arg)

        Parameters
        ----------
        _arg: itkVectorD2

        SetOutputSpacing(self, spacing)

        Parameters
        ----------
        spacing: double const *

        """
        return _itkWarpImageFilterPython.itkWarpImageFilterISS2ISS2IVF22_SetOutputSpacing(self, *args)

    def GetOutputSpacing(self):
        r"""GetOutputSpacing(self) -> itkVectorD2"""
        return _itkWarpImageFilterPython.itkWarpImageFilterISS2ISS2IVF22_GetOutputSpacing(self)

    def SetOutputOrigin(self, *args):
        r"""
        SetOutputOrigin(self, _arg)

        Parameters
        ----------
        _arg: itkPointD2

        SetOutputOrigin(self, origin)

        Parameters
        ----------
        origin: double const *

        """
        return _itkWarpImageFilterPython.itkWarpImageFilterISS2ISS2IVF22_SetOutputOrigin(self, *args)

    def GetOutputOrigin(self):
        r"""GetOutputOrigin(self) -> itkPointD2"""
        return _itkWarpImageFilterPython.itkWarpImageFilterISS2ISS2IVF22_GetOutputOrigin(self)

    def SetOutputDirection(self, _arg):
        r"""
        SetOutputDirection(self, _arg)

        Parameters
        ----------
        _arg: itkMatrixD22

        """
        return _itkWarpImageFilterPython.itkWarpImageFilterISS2ISS2IVF22_SetOutputDirection(self, _arg)

    def GetOutputDirection(self):
        r"""GetOutputDirection(self) -> itkMatrixD22"""
        return _itkWarpImageFilterPython.itkWarpImageFilterISS2ISS2IVF22_GetOutputDirection(self)

    def SetOutputParametersFromImage(self, image):
        r"""
        SetOutputParametersFromImage(self, image)

        Parameters
        ----------
        image: itkImageBase2 const *

        """
        return _itkWarpImageFilterPython.itkWarpImageFilterISS2ISS2IVF22_SetOutputParametersFromImage(self, image)

    def SetOutputStartIndex(self, _arg):
        r"""
        SetOutputStartIndex(self, _arg)

        Parameters
        ----------
        _arg: itkIndex2

        """
        return _itkWarpImageFilterPython.itkWarpImageFilterISS2ISS2IVF22_SetOutputStartIndex(self, _arg)

    def GetOutputStartIndex(self):
        r"""GetOutputStartIndex(self) -> itkIndex2"""
        return _itkWarpImageFilterPython.itkWarpImageFilterISS2ISS2IVF22_GetOutputStartIndex(self)

    def SetOutputSize(self, _arg):
        r"""
        SetOutputSize(self, _arg)

        Parameters
        ----------
        _arg: itkSize2

        """
        return _itkWarpImageFilterPython.itkWarpImageFilterISS2ISS2IVF22_SetOutputSize(self, _arg)

    def GetOutputSize(self):
        r"""GetOutputSize(self) -> itkSize2"""
        return _itkWarpImageFilterPython.itkWarpImageFilterISS2ISS2IVF22_GetOutputSize(self)

    def SetEdgePaddingValue(self, _arg):
        r"""
        SetEdgePaddingValue(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkWarpImageFilterPython.itkWarpImageFilterISS2ISS2IVF22_SetEdgePaddingValue(self, _arg)

    def GetEdgePaddingValue(self):
        r"""GetEdgePaddingValue(self) -> short"""
        return _itkWarpImageFilterPython.itkWarpImageFilterISS2ISS2IVF22_GetEdgePaddingValue(self)

    def GenerateOutputInformation(self):
        r"""GenerateOutputInformation(self)"""
        return _itkWarpImageFilterPython.itkWarpImageFilterISS2ISS2IVF22_GenerateOutputInformation(self)

    def GenerateInputRequestedRegion(self):
        r"""GenerateInputRequestedRegion(self)"""
        return _itkWarpImageFilterPython.itkWarpImageFilterISS2ISS2IVF22_GenerateInputRequestedRegion(self)

    def BeforeThreadedGenerateData(self):
        r"""BeforeThreadedGenerateData(self)"""
        return _itkWarpImageFilterPython.itkWarpImageFilterISS2ISS2IVF22_BeforeThreadedGenerateData(self)

    def AfterThreadedGenerateData(self):
        r"""AfterThreadedGenerateData(self)"""
        return _itkWarpImageFilterPython.itkWarpImageFilterISS2ISS2IVF22_AfterThreadedGenerateData(self)
    SameDimensionCheck1 = _itkWarpImageFilterPython.itkWarpImageFilterISS2ISS2IVF22_SameDimensionCheck1
    
    SameDimensionCheck2 = _itkWarpImageFilterPython.itkWarpImageFilterISS2ISS2IVF22_SameDimensionCheck2
    
    InputHasNumericTraitsCheck = _itkWarpImageFilterPython.itkWarpImageFilterISS2ISS2IVF22_InputHasNumericTraitsCheck
    
    DisplacementFieldHasNumericTraitsCheck = _itkWarpImageFilterPython.itkWarpImageFilterISS2ISS2IVF22_DisplacementFieldHasNumericTraitsCheck
    
    __swig_destroy__ = _itkWarpImageFilterPython.delete_itkWarpImageFilterISS2ISS2IVF22

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkWarpImageFilterISS2ISS2IVF22

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkWarpImageFilterPython.itkWarpImageFilterISS2ISS2IVF22_cast(obj)

    def New(*args, **kargs):
        """New() -> itkWarpImageFilterISS2ISS2IVF22

        Create a new object of the class itkWarpImageFilterISS2ISS2IVF22 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkWarpImageFilterISS2ISS2IVF22.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkWarpImageFilterISS2ISS2IVF22.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkWarpImageFilterISS2ISS2IVF22.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkWarpImageFilterISS2ISS2IVF22 in _itkWarpImageFilterPython:
_itkWarpImageFilterPython.itkWarpImageFilterISS2ISS2IVF22_swigregister(itkWarpImageFilterISS2ISS2IVF22)

def itkWarpImageFilterISS3ISS3IVF33_New():
    return itkWarpImageFilterISS3ISS3IVF33.New()

class itkWarpImageFilterISS3ISS3IVF33(itk.itkImageToImageFilterAPython.itkImageToImageFilterISS3ISS3):
    r"""Proxy of C++ itkWarpImageFilterISS3ISS3IVF33 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkWarpImageFilterISS3ISS3IVF33_Pointer"""
        return _itkWarpImageFilterPython.itkWarpImageFilterISS3ISS3IVF33___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkWarpImageFilterISS3ISS3IVF33_Pointer"""
        return _itkWarpImageFilterPython.itkWarpImageFilterISS3ISS3IVF33_Clone(self)

    def SetDisplacementField(self, _arg):
        r"""
        SetDisplacementField(self, _arg)

        Parameters
        ----------
        _arg: itkImageVF33 const *

        """
        return _itkWarpImageFilterPython.itkWarpImageFilterISS3ISS3IVF33_SetDisplacementField(self, _arg)

    def GetDisplacementField(self):
        r"""GetDisplacementField(self) -> itkImageVF33"""
        return _itkWarpImageFilterPython.itkWarpImageFilterISS3ISS3IVF33_GetDisplacementField(self)

    def SetInterpolator(self, _arg):
        r"""
        SetInterpolator(self, _arg)

        Parameters
        ----------
        _arg: itkInterpolateImageFunctionISS3D *

        """
        return _itkWarpImageFilterPython.itkWarpImageFilterISS3ISS3IVF33_SetInterpolator(self, _arg)

    def GetModifiableInterpolator(self):
        r"""GetModifiableInterpolator(self) -> itkInterpolateImageFunctionISS3D"""
        return _itkWarpImageFilterPython.itkWarpImageFilterISS3ISS3IVF33_GetModifiableInterpolator(self)

    def GetInterpolator(self, *args):
        r"""
        GetInterpolator(self) -> itkInterpolateImageFunctionISS3D
        GetInterpolator(self) -> itkInterpolateImageFunctionISS3D
        """
        return _itkWarpImageFilterPython.itkWarpImageFilterISS3ISS3IVF33_GetInterpolator(self, *args)

    def SetOutputSpacing(self, *args):
        r"""
        SetOutputSpacing(self, _arg)

        Parameters
        ----------
        _arg: itkVectorD3

        SetOutputSpacing(self, spacing)

        Parameters
        ----------
        spacing: double const *

        """
        return _itkWarpImageFilterPython.itkWarpImageFilterISS3ISS3IVF33_SetOutputSpacing(self, *args)

    def GetOutputSpacing(self):
        r"""GetOutputSpacing(self) -> itkVectorD3"""
        return _itkWarpImageFilterPython.itkWarpImageFilterISS3ISS3IVF33_GetOutputSpacing(self)

    def SetOutputOrigin(self, *args):
        r"""
        SetOutputOrigin(self, _arg)

        Parameters
        ----------
        _arg: itkPointD3

        SetOutputOrigin(self, origin)

        Parameters
        ----------
        origin: double const *

        """
        return _itkWarpImageFilterPython.itkWarpImageFilterISS3ISS3IVF33_SetOutputOrigin(self, *args)

    def GetOutputOrigin(self):
        r"""GetOutputOrigin(self) -> itkPointD3"""
        return _itkWarpImageFilterPython.itkWarpImageFilterISS3ISS3IVF33_GetOutputOrigin(self)

    def SetOutputDirection(self, _arg):
        r"""
        SetOutputDirection(self, _arg)

        Parameters
        ----------
        _arg: itkMatrixD33

        """
        return _itkWarpImageFilterPython.itkWarpImageFilterISS3ISS3IVF33_SetOutputDirection(self, _arg)

    def GetOutputDirection(self):
        r"""GetOutputDirection(self) -> itkMatrixD33"""
        return _itkWarpImageFilterPython.itkWarpImageFilterISS3ISS3IVF33_GetOutputDirection(self)

    def SetOutputParametersFromImage(self, image):
        r"""
        SetOutputParametersFromImage(self, image)

        Parameters
        ----------
        image: itkImageBase3 const *

        """
        return _itkWarpImageFilterPython.itkWarpImageFilterISS3ISS3IVF33_SetOutputParametersFromImage(self, image)

    def SetOutputStartIndex(self, _arg):
        r"""
        SetOutputStartIndex(self, _arg)

        Parameters
        ----------
        _arg: itkIndex3

        """
        return _itkWarpImageFilterPython.itkWarpImageFilterISS3ISS3IVF33_SetOutputStartIndex(self, _arg)

    def GetOutputStartIndex(self):
        r"""GetOutputStartIndex(self) -> itkIndex3"""
        return _itkWarpImageFilterPython.itkWarpImageFilterISS3ISS3IVF33_GetOutputStartIndex(self)

    def SetOutputSize(self, _arg):
        r"""
        SetOutputSize(self, _arg)

        Parameters
        ----------
        _arg: itkSize3

        """
        return _itkWarpImageFilterPython.itkWarpImageFilterISS3ISS3IVF33_SetOutputSize(self, _arg)

    def GetOutputSize(self):
        r"""GetOutputSize(self) -> itkSize3"""
        return _itkWarpImageFilterPython.itkWarpImageFilterISS3ISS3IVF33_GetOutputSize(self)

    def SetEdgePaddingValue(self, _arg):
        r"""
        SetEdgePaddingValue(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkWarpImageFilterPython.itkWarpImageFilterISS3ISS3IVF33_SetEdgePaddingValue(self, _arg)

    def GetEdgePaddingValue(self):
        r"""GetEdgePaddingValue(self) -> short"""
        return _itkWarpImageFilterPython.itkWarpImageFilterISS3ISS3IVF33_GetEdgePaddingValue(self)

    def GenerateOutputInformation(self):
        r"""GenerateOutputInformation(self)"""
        return _itkWarpImageFilterPython.itkWarpImageFilterISS3ISS3IVF33_GenerateOutputInformation(self)

    def GenerateInputRequestedRegion(self):
        r"""GenerateInputRequestedRegion(self)"""
        return _itkWarpImageFilterPython.itkWarpImageFilterISS3ISS3IVF33_GenerateInputRequestedRegion(self)

    def BeforeThreadedGenerateData(self):
        r"""BeforeThreadedGenerateData(self)"""
        return _itkWarpImageFilterPython.itkWarpImageFilterISS3ISS3IVF33_BeforeThreadedGenerateData(self)

    def AfterThreadedGenerateData(self):
        r"""AfterThreadedGenerateData(self)"""
        return _itkWarpImageFilterPython.itkWarpImageFilterISS3ISS3IVF33_AfterThreadedGenerateData(self)
    SameDimensionCheck1 = _itkWarpImageFilterPython.itkWarpImageFilterISS3ISS3IVF33_SameDimensionCheck1
    
    SameDimensionCheck2 = _itkWarpImageFilterPython.itkWarpImageFilterISS3ISS3IVF33_SameDimensionCheck2
    
    InputHasNumericTraitsCheck = _itkWarpImageFilterPython.itkWarpImageFilterISS3ISS3IVF33_InputHasNumericTraitsCheck
    
    DisplacementFieldHasNumericTraitsCheck = _itkWarpImageFilterPython.itkWarpImageFilterISS3ISS3IVF33_DisplacementFieldHasNumericTraitsCheck
    
    __swig_destroy__ = _itkWarpImageFilterPython.delete_itkWarpImageFilterISS3ISS3IVF33

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkWarpImageFilterISS3ISS3IVF33

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkWarpImageFilterPython.itkWarpImageFilterISS3ISS3IVF33_cast(obj)

    def New(*args, **kargs):
        """New() -> itkWarpImageFilterISS3ISS3IVF33

        Create a new object of the class itkWarpImageFilterISS3ISS3IVF33 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkWarpImageFilterISS3ISS3IVF33.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkWarpImageFilterISS3ISS3IVF33.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkWarpImageFilterISS3ISS3IVF33.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkWarpImageFilterISS3ISS3IVF33 in _itkWarpImageFilterPython:
_itkWarpImageFilterPython.itkWarpImageFilterISS3ISS3IVF33_swigregister(itkWarpImageFilterISS3ISS3IVF33)

def itkWarpImageFilterIUC2IUC2IVF22_New():
    return itkWarpImageFilterIUC2IUC2IVF22.New()

class itkWarpImageFilterIUC2IUC2IVF22(itk.itkImageToImageFilterAPython.itkImageToImageFilterIUC2IUC2):
    r"""Proxy of C++ itkWarpImageFilterIUC2IUC2IVF22 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkWarpImageFilterIUC2IUC2IVF22_Pointer"""
        return _itkWarpImageFilterPython.itkWarpImageFilterIUC2IUC2IVF22___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkWarpImageFilterIUC2IUC2IVF22_Pointer"""
        return _itkWarpImageFilterPython.itkWarpImageFilterIUC2IUC2IVF22_Clone(self)

    def SetDisplacementField(self, _arg):
        r"""
        SetDisplacementField(self, _arg)

        Parameters
        ----------
        _arg: itkImageVF22 const *

        """
        return _itkWarpImageFilterPython.itkWarpImageFilterIUC2IUC2IVF22_SetDisplacementField(self, _arg)

    def GetDisplacementField(self):
        r"""GetDisplacementField(self) -> itkImageVF22"""
        return _itkWarpImageFilterPython.itkWarpImageFilterIUC2IUC2IVF22_GetDisplacementField(self)

    def SetInterpolator(self, _arg):
        r"""
        SetInterpolator(self, _arg)

        Parameters
        ----------
        _arg: itkInterpolateImageFunctionIUC2D *

        """
        return _itkWarpImageFilterPython.itkWarpImageFilterIUC2IUC2IVF22_SetInterpolator(self, _arg)

    def GetModifiableInterpolator(self):
        r"""GetModifiableInterpolator(self) -> itkInterpolateImageFunctionIUC2D"""
        return _itkWarpImageFilterPython.itkWarpImageFilterIUC2IUC2IVF22_GetModifiableInterpolator(self)

    def GetInterpolator(self, *args):
        r"""
        GetInterpolator(self) -> itkInterpolateImageFunctionIUC2D
        GetInterpolator(self) -> itkInterpolateImageFunctionIUC2D
        """
        return _itkWarpImageFilterPython.itkWarpImageFilterIUC2IUC2IVF22_GetInterpolator(self, *args)

    def SetOutputSpacing(self, *args):
        r"""
        SetOutputSpacing(self, _arg)

        Parameters
        ----------
        _arg: itkVectorD2

        SetOutputSpacing(self, spacing)

        Parameters
        ----------
        spacing: double const *

        """
        return _itkWarpImageFilterPython.itkWarpImageFilterIUC2IUC2IVF22_SetOutputSpacing(self, *args)

    def GetOutputSpacing(self):
        r"""GetOutputSpacing(self) -> itkVectorD2"""
        return _itkWarpImageFilterPython.itkWarpImageFilterIUC2IUC2IVF22_GetOutputSpacing(self)

    def SetOutputOrigin(self, *args):
        r"""
        SetOutputOrigin(self, _arg)

        Parameters
        ----------
        _arg: itkPointD2

        SetOutputOrigin(self, origin)

        Parameters
        ----------
        origin: double const *

        """
        return _itkWarpImageFilterPython.itkWarpImageFilterIUC2IUC2IVF22_SetOutputOrigin(self, *args)

    def GetOutputOrigin(self):
        r"""GetOutputOrigin(self) -> itkPointD2"""
        return _itkWarpImageFilterPython.itkWarpImageFilterIUC2IUC2IVF22_GetOutputOrigin(self)

    def SetOutputDirection(self, _arg):
        r"""
        SetOutputDirection(self, _arg)

        Parameters
        ----------
        _arg: itkMatrixD22

        """
        return _itkWarpImageFilterPython.itkWarpImageFilterIUC2IUC2IVF22_SetOutputDirection(self, _arg)

    def GetOutputDirection(self):
        r"""GetOutputDirection(self) -> itkMatrixD22"""
        return _itkWarpImageFilterPython.itkWarpImageFilterIUC2IUC2IVF22_GetOutputDirection(self)

    def SetOutputParametersFromImage(self, image):
        r"""
        SetOutputParametersFromImage(self, image)

        Parameters
        ----------
        image: itkImageBase2 const *

        """
        return _itkWarpImageFilterPython.itkWarpImageFilterIUC2IUC2IVF22_SetOutputParametersFromImage(self, image)

    def SetOutputStartIndex(self, _arg):
        r"""
        SetOutputStartIndex(self, _arg)

        Parameters
        ----------
        _arg: itkIndex2

        """
        return _itkWarpImageFilterPython.itkWarpImageFilterIUC2IUC2IVF22_SetOutputStartIndex(self, _arg)

    def GetOutputStartIndex(self):
        r"""GetOutputStartIndex(self) -> itkIndex2"""
        return _itkWarpImageFilterPython.itkWarpImageFilterIUC2IUC2IVF22_GetOutputStartIndex(self)

    def SetOutputSize(self, _arg):
        r"""
        SetOutputSize(self, _arg)

        Parameters
        ----------
        _arg: itkSize2

        """
        return _itkWarpImageFilterPython.itkWarpImageFilterIUC2IUC2IVF22_SetOutputSize(self, _arg)

    def GetOutputSize(self):
        r"""GetOutputSize(self) -> itkSize2"""
        return _itkWarpImageFilterPython.itkWarpImageFilterIUC2IUC2IVF22_GetOutputSize(self)

    def SetEdgePaddingValue(self, _arg):
        r"""
        SetEdgePaddingValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkWarpImageFilterPython.itkWarpImageFilterIUC2IUC2IVF22_SetEdgePaddingValue(self, _arg)

    def GetEdgePaddingValue(self):
        r"""GetEdgePaddingValue(self) -> unsigned char"""
        return _itkWarpImageFilterPython.itkWarpImageFilterIUC2IUC2IVF22_GetEdgePaddingValue(self)

    def GenerateOutputInformation(self):
        r"""GenerateOutputInformation(self)"""
        return _itkWarpImageFilterPython.itkWarpImageFilterIUC2IUC2IVF22_GenerateOutputInformation(self)

    def GenerateInputRequestedRegion(self):
        r"""GenerateInputRequestedRegion(self)"""
        return _itkWarpImageFilterPython.itkWarpImageFilterIUC2IUC2IVF22_GenerateInputRequestedRegion(self)

    def BeforeThreadedGenerateData(self):
        r"""BeforeThreadedGenerateData(self)"""
        return _itkWarpImageFilterPython.itkWarpImageFilterIUC2IUC2IVF22_BeforeThreadedGenerateData(self)

    def AfterThreadedGenerateData(self):
        r"""AfterThreadedGenerateData(self)"""
        return _itkWarpImageFilterPython.itkWarpImageFilterIUC2IUC2IVF22_AfterThreadedGenerateData(self)
    SameDimensionCheck1 = _itkWarpImageFilterPython.itkWarpImageFilterIUC2IUC2IVF22_SameDimensionCheck1
    
    SameDimensionCheck2 = _itkWarpImageFilterPython.itkWarpImageFilterIUC2IUC2IVF22_SameDimensionCheck2
    
    InputHasNumericTraitsCheck = _itkWarpImageFilterPython.itkWarpImageFilterIUC2IUC2IVF22_InputHasNumericTraitsCheck
    
    DisplacementFieldHasNumericTraitsCheck = _itkWarpImageFilterPython.itkWarpImageFilterIUC2IUC2IVF22_DisplacementFieldHasNumericTraitsCheck
    
    __swig_destroy__ = _itkWarpImageFilterPython.delete_itkWarpImageFilterIUC2IUC2IVF22

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkWarpImageFilterIUC2IUC2IVF22

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkWarpImageFilterPython.itkWarpImageFilterIUC2IUC2IVF22_cast(obj)

    def New(*args, **kargs):
        """New() -> itkWarpImageFilterIUC2IUC2IVF22

        Create a new object of the class itkWarpImageFilterIUC2IUC2IVF22 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkWarpImageFilterIUC2IUC2IVF22.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkWarpImageFilterIUC2IUC2IVF22.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkWarpImageFilterIUC2IUC2IVF22.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkWarpImageFilterIUC2IUC2IVF22 in _itkWarpImageFilterPython:
_itkWarpImageFilterPython.itkWarpImageFilterIUC2IUC2IVF22_swigregister(itkWarpImageFilterIUC2IUC2IVF22)

def itkWarpImageFilterIUC3IUC3IVF33_New():
    return itkWarpImageFilterIUC3IUC3IVF33.New()

class itkWarpImageFilterIUC3IUC3IVF33(itk.itkImageToImageFilterAPython.itkImageToImageFilterIUC3IUC3):
    r"""Proxy of C++ itkWarpImageFilterIUC3IUC3IVF33 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkWarpImageFilterIUC3IUC3IVF33_Pointer"""
        return _itkWarpImageFilterPython.itkWarpImageFilterIUC3IUC3IVF33___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkWarpImageFilterIUC3IUC3IVF33_Pointer"""
        return _itkWarpImageFilterPython.itkWarpImageFilterIUC3IUC3IVF33_Clone(self)

    def SetDisplacementField(self, _arg):
        r"""
        SetDisplacementField(self, _arg)

        Parameters
        ----------
        _arg: itkImageVF33 const *

        """
        return _itkWarpImageFilterPython.itkWarpImageFilterIUC3IUC3IVF33_SetDisplacementField(self, _arg)

    def GetDisplacementField(self):
        r"""GetDisplacementField(self) -> itkImageVF33"""
        return _itkWarpImageFilterPython.itkWarpImageFilterIUC3IUC3IVF33_GetDisplacementField(self)

    def SetInterpolator(self, _arg):
        r"""
        SetInterpolator(self, _arg)

        Parameters
        ----------
        _arg: itkInterpolateImageFunctionIUC3D *

        """
        return _itkWarpImageFilterPython.itkWarpImageFilterIUC3IUC3IVF33_SetInterpolator(self, _arg)

    def GetModifiableInterpolator(self):
        r"""GetModifiableInterpolator(self) -> itkInterpolateImageFunctionIUC3D"""
        return _itkWarpImageFilterPython.itkWarpImageFilterIUC3IUC3IVF33_GetModifiableInterpolator(self)

    def GetInterpolator(self, *args):
        r"""
        GetInterpolator(self) -> itkInterpolateImageFunctionIUC3D
        GetInterpolator(self) -> itkInterpolateImageFunctionIUC3D
        """
        return _itkWarpImageFilterPython.itkWarpImageFilterIUC3IUC3IVF33_GetInterpolator(self, *args)

    def SetOutputSpacing(self, *args):
        r"""
        SetOutputSpacing(self, _arg)

        Parameters
        ----------
        _arg: itkVectorD3

        SetOutputSpacing(self, spacing)

        Parameters
        ----------
        spacing: double const *

        """
        return _itkWarpImageFilterPython.itkWarpImageFilterIUC3IUC3IVF33_SetOutputSpacing(self, *args)

    def GetOutputSpacing(self):
        r"""GetOutputSpacing(self) -> itkVectorD3"""
        return _itkWarpImageFilterPython.itkWarpImageFilterIUC3IUC3IVF33_GetOutputSpacing(self)

    def SetOutputOrigin(self, *args):
        r"""
        SetOutputOrigin(self, _arg)

        Parameters
        ----------
        _arg: itkPointD3

        SetOutputOrigin(self, origin)

        Parameters
        ----------
        origin: double const *

        """
        return _itkWarpImageFilterPython.itkWarpImageFilterIUC3IUC3IVF33_SetOutputOrigin(self, *args)

    def GetOutputOrigin(self):
        r"""GetOutputOrigin(self) -> itkPointD3"""
        return _itkWarpImageFilterPython.itkWarpImageFilterIUC3IUC3IVF33_GetOutputOrigin(self)

    def SetOutputDirection(self, _arg):
        r"""
        SetOutputDirection(self, _arg)

        Parameters
        ----------
        _arg: itkMatrixD33

        """
        return _itkWarpImageFilterPython.itkWarpImageFilterIUC3IUC3IVF33_SetOutputDirection(self, _arg)

    def GetOutputDirection(self):
        r"""GetOutputDirection(self) -> itkMatrixD33"""
        return _itkWarpImageFilterPython.itkWarpImageFilterIUC3IUC3IVF33_GetOutputDirection(self)

    def SetOutputParametersFromImage(self, image):
        r"""
        SetOutputParametersFromImage(self, image)

        Parameters
        ----------
        image: itkImageBase3 const *

        """
        return _itkWarpImageFilterPython.itkWarpImageFilterIUC3IUC3IVF33_SetOutputParametersFromImage(self, image)

    def SetOutputStartIndex(self, _arg):
        r"""
        SetOutputStartIndex(self, _arg)

        Parameters
        ----------
        _arg: itkIndex3

        """
        return _itkWarpImageFilterPython.itkWarpImageFilterIUC3IUC3IVF33_SetOutputStartIndex(self, _arg)

    def GetOutputStartIndex(self):
        r"""GetOutputStartIndex(self) -> itkIndex3"""
        return _itkWarpImageFilterPython.itkWarpImageFilterIUC3IUC3IVF33_GetOutputStartIndex(self)

    def SetOutputSize(self, _arg):
        r"""
        SetOutputSize(self, _arg)

        Parameters
        ----------
        _arg: itkSize3

        """
        return _itkWarpImageFilterPython.itkWarpImageFilterIUC3IUC3IVF33_SetOutputSize(self, _arg)

    def GetOutputSize(self):
        r"""GetOutputSize(self) -> itkSize3"""
        return _itkWarpImageFilterPython.itkWarpImageFilterIUC3IUC3IVF33_GetOutputSize(self)

    def SetEdgePaddingValue(self, _arg):
        r"""
        SetEdgePaddingValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkWarpImageFilterPython.itkWarpImageFilterIUC3IUC3IVF33_SetEdgePaddingValue(self, _arg)

    def GetEdgePaddingValue(self):
        r"""GetEdgePaddingValue(self) -> unsigned char"""
        return _itkWarpImageFilterPython.itkWarpImageFilterIUC3IUC3IVF33_GetEdgePaddingValue(self)

    def GenerateOutputInformation(self):
        r"""GenerateOutputInformation(self)"""
        return _itkWarpImageFilterPython.itkWarpImageFilterIUC3IUC3IVF33_GenerateOutputInformation(self)

    def GenerateInputRequestedRegion(self):
        r"""GenerateInputRequestedRegion(self)"""
        return _itkWarpImageFilterPython.itkWarpImageFilterIUC3IUC3IVF33_GenerateInputRequestedRegion(self)

    def BeforeThreadedGenerateData(self):
        r"""BeforeThreadedGenerateData(self)"""
        return _itkWarpImageFilterPython.itkWarpImageFilterIUC3IUC3IVF33_BeforeThreadedGenerateData(self)

    def AfterThreadedGenerateData(self):
        r"""AfterThreadedGenerateData(self)"""
        return _itkWarpImageFilterPython.itkWarpImageFilterIUC3IUC3IVF33_AfterThreadedGenerateData(self)
    SameDimensionCheck1 = _itkWarpImageFilterPython.itkWarpImageFilterIUC3IUC3IVF33_SameDimensionCheck1
    
    SameDimensionCheck2 = _itkWarpImageFilterPython.itkWarpImageFilterIUC3IUC3IVF33_SameDimensionCheck2
    
    InputHasNumericTraitsCheck = _itkWarpImageFilterPython.itkWarpImageFilterIUC3IUC3IVF33_InputHasNumericTraitsCheck
    
    DisplacementFieldHasNumericTraitsCheck = _itkWarpImageFilterPython.itkWarpImageFilterIUC3IUC3IVF33_DisplacementFieldHasNumericTraitsCheck
    
    __swig_destroy__ = _itkWarpImageFilterPython.delete_itkWarpImageFilterIUC3IUC3IVF33

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkWarpImageFilterIUC3IUC3IVF33

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkWarpImageFilterPython.itkWarpImageFilterIUC3IUC3IVF33_cast(obj)

    def New(*args, **kargs):
        """New() -> itkWarpImageFilterIUC3IUC3IVF33

        Create a new object of the class itkWarpImageFilterIUC3IUC3IVF33 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkWarpImageFilterIUC3IUC3IVF33.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkWarpImageFilterIUC3IUC3IVF33.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkWarpImageFilterIUC3IUC3IVF33.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkWarpImageFilterIUC3IUC3IVF33 in _itkWarpImageFilterPython:
_itkWarpImageFilterPython.itkWarpImageFilterIUC3IUC3IVF33_swigregister(itkWarpImageFilterIUC3IUC3IVF33)

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def warp_image_filter(*args: itkt.ImageLike,  displacement_field: itkt.Image=..., interpolator: itkt.InterpolateImageFunction=..., output_spacing: Sequence[float]=..., output_origin: Sequence[float]=..., output_direction=..., output_parameters_from_image: itkt.ImageBase=..., output_start_index: Sequence[int]=..., output_size: Sequence[int]=..., edge_padding_value: int=...,**kwargs)-> itkt.ImageSourceReturn:
    """Functional interface for WarpImageFilter"""
    import itk

    kwarg_typehints = { 'displacement_field':displacement_field,'interpolator':interpolator,'output_spacing':output_spacing,'output_origin':output_origin,'output_direction':output_direction,'output_parameters_from_image':output_parameters_from_image,'output_start_index':output_start_index,'output_size':output_size,'edge_padding_value':edge_padding_value }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.WarpImageFilter.New(*args, **kwargs)

    return instance.__internal_call__()

def warp_image_filter_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKImageGrid.WarpImageFilter
    warp_image_filter.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    warp_image_filter.__doc__ = filter_object.__doc__



